==> estateplat-common-1.2.3-20180109.064205-10-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfHtmbkfs.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:chenjia@gtmap.cn">sunchao</a>
 * @version 1.0, 2017/12/20
 * @description 开发商合同模板
 */
@Table(name = "fcjy_xjspf_htmbkfs")
public class FcjyXjspfHtmbkfs {
    @Id
    private String mbid;//模板id
    private String fdckfqymc;//房地产开发企业名称
    private Long fdckfqybh;//房地产开发企业编号
    private String bzmbid;//标准模板id
    private String mbmc;//模板名称
    private String bz;//备注
    private String nr;//内容

    public String getMbid() {
        return mbid;
    }

    public void setMbid(String mbid) {
        this.mbid = mbid;
    }

    public String getFdckfqymc() {
        return fdckfqymc;
    }

    public void setFdckfqymc(String fdckfqymc) {
        this.fdckfqymc = fdckfqymc;
    }

    public Long getFdckfqybh() {
        return fdckfqybh;
    }

    public void setFdckfqybh(Long fdckfqybh) {
        this.fdckfqybh = fdckfqybh;
    }

    public String getBzmbid() {
        return bzmbid;
    }

    public void setBzmbid(String bzmbid) {
        this.bzmbid = bzmbid;
    }

    public String getMbmc() {
        return mbmc;
    }

    public void setMbmc(String mbmc) {
        this.mbmc = mbmc;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getNr() {
        return nr;
    }

    public void setNr(String nr) {
        this.nr = nr;
    }
}

==> estateplat-common-1.2.4-20231227.085211-1208-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfHtmbkfs.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * @author <a href="mailto:chenjia@gtmap.cn">sunchao</a>
 * @version 1.0, 2017/12/20
 * @description 开发商合同模板
 */
@Table(name = "fcjy_xjspf_htmbkfs")
public class FcjyXjspfHtmbkfs implements Serializable {
    @Id
    private String mbid;//模板id
    private String fdckfqymc;//房地产开发企业名称
    private Long fdckfqybh;//房地产开发企业编号
    private String bzmbid;//标准模板id
    private String mbmc;//模板名称
    private String bz;//备注
    private String nr;//内容

    public String getMbid() {
        return mbid;
    }

    public void setMbid(String mbid) {
        this.mbid = mbid;
    }

    public String getFdckfqymc() {
        return fdckfqymc;
    }

    public void setFdckfqymc(String fdckfqymc) {
        this.fdckfqymc = fdckfqymc;
    }

    public Long getFdckfqybh() {
        return fdckfqybh;
    }

    public void setFdckfqybh(Long fdckfqybh) {
        this.fdckfqybh = fdckfqybh;
    }

    public String getBzmbid() {
        return bzmbid;
    }

    public void setBzmbid(String bzmbid) {
        this.bzmbid = bzmbid;
    }

    public String getMbmc() {
        return mbmc;
    }

    public void setMbmc(String mbmc) {
        this.mbmc = mbmc;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getNr() {
        return nr;
    }

    public void setNr(String nr) {
        this.nr = nr;
    }
}
